==> trellis_python-2.15.0.tar.gz: trellis_python-2.15.0/CHANGELOG.md <==
# Changelog

## 2.15.0 (2024-12-05)

Full Changelog: [v2.14.0...v2.15.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.14.0...v2.15.0)

### Features

* **api:** api update ([#63](https://github.com/Trellis-insights/trellis-python-sdk/issues/63)) ([790fbfe](https://github.com/Trellis-insights/trellis-python-sdk/commit/790fbfe7fa61ef7e758af4ae1d95db25c9ab5ee1))

## 2.14.0 (2024-12-04)

Full Changelog: [v2.13.0...v2.14.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.13.0...v2.14.0)

### Features

* **api:** api update ([#61](https://github.com/Trellis-insights/trellis-python-sdk/issues/61)) ([bf05d96](https://github.com/Trellis-insights/trellis-python-sdk/commit/bf05d96956c829cf59e1d038636da8f918a672e8))


### Chores

* **internal:** bump pyright ([#59](https://github.com/Trellis-insights/trellis-python-sdk/issues/59)) ([037d1ad](https://github.com/Trellis-insights/trellis-python-sdk/commit/037d1ade785e1bf8f2e3e166490cc1c8fafea389))

## 2.13.0 (2024-12-03)

Full Changelog: [v2.12.0...v2.13.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.12.0...v2.13.0)

### Features

* **api:** api update ([#56](https://github.com/Trellis-insights/trellis-python-sdk/issues/56)) ([624e1fb](https://github.com/Trellis-insights/trellis-python-sdk/commit/624e1fb6b4c1700763bd693e4a4c09efc0043375))

## 2.12.0 (2024-12-03)

Full Changelog: [v2.11.1...v2.12.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.11.1...v2.12.0)

### Features

* **api:** api update ([#53](https://github.com/Trellis-insights/trellis-python-sdk/issues/53)) ([099960c](https://github.com/Trellis-insights/trellis-python-sdk/commit/099960c513703f9ef4e07645c5bda29f59f1622d))

## 2.11.1 (2024-11-30)

Full Changelog: [v2.11.0...v2.11.1](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.11.0...v2.11.1)

### Bug Fixes

* **client:** compat with new httpx 0.28.0 release ([#50](https://github.com/Trellis-insights/trellis-python-sdk/issues/50)) ([58d5ff4](https://github.com/Trellis-insights/trellis-python-sdk/commit/58d5ff46fe2eac01eae08a159d5a3a6cf7c44d63))


### Chores

* **internal:** codegen related update ([#51](https://github.com/Trellis-insights/trellis-python-sdk/issues/51)) ([42b53d2](https://github.com/Trellis-insights/trellis-python-sdk/commit/42b53d25fd7ecdbea8d3448c876a160d23b48b7b))
* **internal:** exclude mypy from running on tests ([#49](https://github.com/Trellis-insights/trellis-python-sdk/issues/49)) ([25c6624](https://github.com/Trellis-insights/trellis-python-sdk/commit/25c66242d5e38467524170b65c4feb8fa3dadcf7))
* **internal:** fix compat model_dump method when warnings are passed ([#45](https://github.com/Trellis-insights/trellis-python-sdk/issues/45)) ([1414574](https://github.com/Trellis-insights/trellis-python-sdk/commit/141457421701d0e421b0f0a3d8ac9150812ca824))
* remove now unused `cached-property` dep ([#48](https://github.com/Trellis-insights/trellis-python-sdk/issues/48)) ([f5f0514](https://github.com/Trellis-insights/trellis-python-sdk/commit/f5f0514c7ca257734938d70bb95ba4bacc196445))


### Documentation

* add info log level to readme ([#47](https://github.com/Trellis-insights/trellis-python-sdk/issues/47)) ([f4d4098](https://github.com/Trellis-insights/trellis-python-sdk/commit/f4d40980ee537f17c5ffc4b64dc6c377204cee90))

## 2.11.0 (2024-11-22)

Full Changelog: [v2.10.0...v2.11.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.10.0...v2.11.0)

### Features

* **api:** api update ([#42](https://github.com/Trellis-insights/trellis-python-sdk/issues/42)) ([573894d](https://github.com/Trellis-insights/trellis-python-sdk/commit/573894d1c1c73c707e2266c6a62c77c93395864e))

## 2.10.0 (2024-11-21)

Full Changelog: [v2.9.0...v2.10.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.9.0...v2.10.0)

### Features

* **api:** api update ([#39](https://github.com/Trellis-insights/trellis-python-sdk/issues/39)) ([8339ef2](https://github.com/Trellis-insights/trellis-python-sdk/commit/8339ef2482e6717f9c637d2cb0f33577a62a124f))

## 2.9.0 (2024-11-20)

Full Changelog: [v2.8.0...v2.9.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.8.0...v2.9.0)

### Features

* **api:** api update ([#36](https://github.com/Trellis-insights/trellis-python-sdk/issues/36)) ([28bd739](https://github.com/Trellis-insights/trellis-python-sdk/commit/28bd739007f8abf80c585972688b070247089f4b))

## 2.8.0 (2024-11-19)

Full Changelog: [v2.7.0...v2.8.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.7.0...v2.8.0)

### Features

* **api:** api update ([#34](https://github.com/Trellis-insights/trellis-python-sdk/issues/34)) ([78e7e72](https://github.com/Trellis-insights/trellis-python-sdk/commit/78e7e7296a8dd92930c7686464038c4db3eb2e69))


### Chores

* rebuild project due to codegen change ([#31](https://github.com/Trellis-insights/trellis-python-sdk/issues/31)) ([8f4e063](https://github.com/Trellis-insights/trellis-python-sdk/commit/8f4e063760250eb837c5108c10fa008fb972cd36))
* rebuild project due to codegen change ([#33](https://github.com/Trellis-insights/trellis-python-sdk/issues/33)) ([f2741e6](https://github.com/Trellis-insights/trellis-python-sdk/commit/f2741e603647352259927f36690be8749ef95ad1))

## 2.7.0 (2024-11-15)

Full Changelog: [v2.6.0...v2.7.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.6.0...v2.7.0)

### Features

* **api:** api update ([#28](https://github.com/Trellis-insights/trellis-python-sdk/issues/28)) ([c9dd3eb](https://github.com/Trellis-insights/trellis-python-sdk/commit/c9dd3ebd388450811ce803cf2d50db12a953324c))

## 2.6.0 (2024-11-14)

Full Changelog: [v2.5.0...v2.6.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.5.0...v2.6.0)

### Features

* **api:** api update ([#25](https://github.com/Trellis-insights/trellis-python-sdk/issues/25)) ([5d2edd6](https://github.com/Trellis-insights/trellis-python-sdk/commit/5d2edd6542a79ba9869c85d4e5393c22dcef5b30))

## 2.5.0 (2024-11-12)

Full Changelog: [v2.4.0...v2.5.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.4.0...v2.5.0)

### Features

* **api:** api update ([#23](https://github.com/Trellis-insights/trellis-python-sdk/issues/23)) ([ff17ba8](https://github.com/Trellis-insights/trellis-python-sdk/commit/ff17ba891278e8a0b020dd96ec7779d72ead61c4))


### Chores

* rebuild project due to codegen change ([#21](https://github.com/Trellis-insights/trellis-python-sdk/issues/21)) ([d837a3c](https://github.com/Trellis-insights/trellis-python-sdk/commit/d837a3ccc1471ca619f97ee42f7014ee1711b8b0))

## 2.4.0 (2024-11-11)

Full Changelog: [v2.3.0...v2.4.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.3.0...v2.4.0)

### Features

* **api:** api update ([#18](https://github.com/Trellis-insights/trellis-python-sdk/issues/18)) ([bb5ab13](https://github.com/Trellis-insights/trellis-python-sdk/commit/bb5ab132cfc7f0576aa5ea0ed21e8e3bb622d684))

## 2.3.0 (2024-11-10)

Full Changelog: [v2.2.0...v2.3.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.2.0...v2.3.0)

### Features

* **api:** api update ([#15](https://github.com/Trellis-insights/trellis-python-sdk/issues/15)) ([6b673e1](https://github.com/Trellis-insights/trellis-python-sdk/commit/6b673e1a993e881471a55a5a16923a44b5bc9eae))

## 2.2.0 (2024-11-10)

Full Changelog: [v2.1.0...v2.2.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.1.0...v2.2.0)

### Features

* **api:** manual updates ([#12](https://github.com/Trellis-insights/trellis-python-sdk/issues/12)) ([f17a6d7](https://github.com/Trellis-insights/trellis-python-sdk/commit/f17a6d79b8e757344a6ddef9b5210837b7907e65))

## 2.1.0 (2024-11-10)

Full Changelog: [v2.0.0...v2.1.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.0.0...v2.1.0)

### Features

* **api:** api update ([#10](https://github.com/Trellis-insights/trellis-python-sdk/issues/10)) ([ebdfa0f](https://github.com/Trellis-insights/trellis-python-sdk/commit/ebdfa0fc9e6ca38ad74fa0f7a4cc09a6d0e5f824))
* **api:** api update ([#8](https://github.com/Trellis-insights/trellis-python-sdk/issues/8)) ([d7eadfc](https://github.com/Trellis-insights/trellis-python-sdk/commit/d7eadfcb12a6433ef6e2fd8e855d101ed0448a5f))

## 2.0.0 (2024-11-07)

Full Changelog: [v1.0.0...v2.0.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v1.0.0...v2.0.0)

### Chores

* update SDK settings ([#5](https://github.com/Trellis-insights/trellis-python-sdk/issues/5)) ([d244250](https://github.com/Trellis-insights/trellis-python-sdk/commit/d244250f38ee062e0885904076fd841ca27593f1))

## 1.0.0 (2024-11-04)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* go live ([#1](https://github.com/Trellis-insights/trellis-python-sdk/issues/1)) ([15992d4](https://github.com/Trellis-insights/trellis-python-sdk/commit/15992d4245d6e4d1c8a82c18c854ffa74d8090c4))
* update SDK settings ([#3](https://github.com/Trellis-insights/trellis-python-sdk/issues/3)) ([161e906](https://github.com/Trellis-insights/trellis-python-sdk/commit/161e90633a5a1d70c5c8a87a507bbca521ecb2ba))

==> trellis_python-2.16.0.tar.gz: trellis_python-2.16.0/CHANGELOG.md <==
# Changelog

## 2.16.0 (2024-12-09)

Full Changelog: [v2.15.0...v2.16.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.15.0...v2.16.0)

### Features

* **api:** api update ([#68](https://github.com/Trellis-insights/trellis-python-sdk/issues/68)) ([a6de665](https://github.com/Trellis-insights/trellis-python-sdk/commit/a6de66565f7c76c2bb1f47d40ff281ad9abb9f9a))


### Chores

* make the `Omit` type public ([#66](https://github.com/Trellis-insights/trellis-python-sdk/issues/66)) ([66fa221](https://github.com/Trellis-insights/trellis-python-sdk/commit/66fa221d0a2827d9cc8cb9ca04b5755505ba561a))

## 2.15.0 (2024-12-05)

Full Changelog: [v2.14.0...v2.15.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.14.0...v2.15.0)

### Features

* **api:** api update ([#63](https://github.com/Trellis-insights/trellis-python-sdk/issues/63)) ([790fbfe](https://github.com/Trellis-insights/trellis-python-sdk/commit/790fbfe7fa61ef7e758af4ae1d95db25c9ab5ee1))

## 2.14.0 (2024-12-04)

Full Changelog: [v2.13.0...v2.14.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.13.0...v2.14.0)

### Features

* **api:** api update ([#61](https://github.com/Trellis-insights/trellis-python-sdk/issues/61)) ([bf05d96](https://github.com/Trellis-insights/trellis-python-sdk/commit/bf05d96956c829cf59e1d038636da8f918a672e8))


### Chores

* **internal:** bump pyright ([#59](https://github.com/Trellis-insights/trellis-python-sdk/issues/59)) ([037d1ad](https://github.com/Trellis-insights/trellis-python-sdk/commit/037d1ade785e1bf8f2e3e166490cc1c8fafea389))

## 2.13.0 (2024-12-03)

Full Changelog: [v2.12.0...v2.13.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.12.0...v2.13.0)

### Features

* **api:** api update ([#56](https://github.com/Trellis-insights/trellis-python-sdk/issues/56)) ([624e1fb](https://github.com/Trellis-insights/trellis-python-sdk/commit/624e1fb6b4c1700763bd693e4a4c09efc0043375))

## 2.12.0 (2024-12-03)

Full Changelog: [v2.11.1...v2.12.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.11.1...v2.12.0)

### Features

* **api:** api update ([#53](https://github.com/Trellis-insights/trellis-python-sdk/issues/53)) ([099960c](https://github.com/Trellis-insights/trellis-python-sdk/commit/099960c513703f9ef4e07645c5bda29f59f1622d))

## 2.11.1 (2024-11-30)

Full Changelog: [v2.11.0...v2.11.1](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.11.0...v2.11.1)

### Bug Fixes

* **client:** compat with new httpx 0.28.0 release ([#50](https://github.com/Trellis-insights/trellis-python-sdk/issues/50)) ([58d5ff4](https://github.com/Trellis-insights/trellis-python-sdk/commit/58d5ff46fe2eac01eae08a159d5a3a6cf7c44d63))


### Chores

* **internal:** codegen related update ([#51](https://github.com/Trellis-insights/trellis-python-sdk/issues/51)) ([42b53d2](https://github.com/Trellis-insights/trellis-python-sdk/commit/42b53d25fd7ecdbea8d3448c876a160d23b48b7b))
* **internal:** exclude mypy from running on tests ([#49](https://github.com/Trellis-insights/trellis-python-sdk/issues/49)) ([25c6624](https://github.com/Trellis-insights/trellis-python-sdk/commit/25c66242d5e38467524170b65c4feb8fa3dadcf7))
* **internal:** fix compat model_dump method when warnings are passed ([#45](https://github.com/Trellis-insights/trellis-python-sdk/issues/45)) ([1414574](https://github.com/Trellis-insights/trellis-python-sdk/commit/141457421701d0e421b0f0a3d8ac9150812ca824))
* remove now unused `cached-property` dep ([#48](https://github.com/Trellis-insights/trellis-python-sdk/issues/48)) ([f5f0514](https://github.com/Trellis-insights/trellis-python-sdk/commit/f5f0514c7ca257734938d70bb95ba4bacc196445))


### Documentation

* add info log level to readme ([#47](https://github.com/Trellis-insights/trellis-python-sdk/issues/47)) ([f4d4098](https://github.com/Trellis-insights/trellis-python-sdk/commit/f4d40980ee537f17c5ffc4b64dc6c377204cee90))

## 2.11.0 (2024-11-22)

Full Changelog: [v2.10.0...v2.11.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.10.0...v2.11.0)

### Features

* **api:** api update ([#42](https://github.com/Trellis-insights/trellis-python-sdk/issues/42)) ([573894d](https://github.com/Trellis-insights/trellis-python-sdk/commit/573894d1c1c73c707e2266c6a62c77c93395864e))

## 2.10.0 (2024-11-21)

Full Changelog: [v2.9.0...v2.10.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.9.0...v2.10.0)

### Features

* **api:** api update ([#39](https://github.com/Trellis-insights/trellis-python-sdk/issues/39)) ([8339ef2](https://github.com/Trellis-insights/trellis-python-sdk/commit/8339ef2482e6717f9c637d2cb0f33577a62a124f))

## 2.9.0 (2024-11-20)

Full Changelog: [v2.8.0...v2.9.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.8.0...v2.9.0)

### Features

* **api:** api update ([#36](https://github.com/Trellis-insights/trellis-python-sdk/issues/36)) ([28bd739](https://github.com/Trellis-insights/trellis-python-sdk/commit/28bd739007f8abf80c585972688b070247089f4b))

## 2.8.0 (2024-11-19)

Full Changelog: [v2.7.0...v2.8.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.7.0...v2.8.0)

### Features

* **api:** api update ([#34](https://github.com/Trellis-insights/trellis-python-sdk/issues/34)) ([78e7e72](https://github.com/Trellis-insights/trellis-python-sdk/commit/78e7e7296a8dd92930c7686464038c4db3eb2e69))


### Chores

* rebuild project due to codegen change ([#31](https://github.com/Trellis-insights/trellis-python-sdk/issues/31)) ([8f4e063](https://github.com/Trellis-insights/trellis-python-sdk/commit/8f4e063760250eb837c5108c10fa008fb972cd36))
* rebuild project due to codegen change ([#33](https://github.com/Trellis-insights/trellis-python-sdk/issues/33)) ([f2741e6](https://github.com/Trellis-insights/trellis-python-sdk/commit/f2741e603647352259927f36690be8749ef95ad1))

## 2.7.0 (2024-11-15)

Full Changelog: [v2.6.0...v2.7.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.6.0...v2.7.0)

### Features

* **api:** api update ([#28](https://github.com/Trellis-insights/trellis-python-sdk/issues/28)) ([c9dd3eb](https://github.com/Trellis-insights/trellis-python-sdk/commit/c9dd3ebd388450811ce803cf2d50db12a953324c))

## 2.6.0 (2024-11-14)

Full Changelog: [v2.5.0...v2.6.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.5.0...v2.6.0)

### Features

* **api:** api update ([#25](https://github.com/Trellis-insights/trellis-python-sdk/issues/25)) ([5d2edd6](https://github.com/Trellis-insights/trellis-python-sdk/commit/5d2edd6542a79ba9869c85d4e5393c22dcef5b30))

## 2.5.0 (2024-11-12)

Full Changelog: [v2.4.0...v2.5.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.4.0...v2.5.0)

### Features

* **api:** api update ([#23](https://github.com/Trellis-insights/trellis-python-sdk/issues/23)) ([ff17ba8](https://github.com/Trellis-insights/trellis-python-sdk/commit/ff17ba891278e8a0b020dd96ec7779d72ead61c4))


### Chores

* rebuild project due to codegen change ([#21](https://github.com/Trellis-insights/trellis-python-sdk/issues/21)) ([d837a3c](https://github.com/Trellis-insights/trellis-python-sdk/commit/d837a3ccc1471ca619f97ee42f7014ee1711b8b0))

## 2.4.0 (2024-11-11)

Full Changelog: [v2.3.0...v2.4.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.3.0...v2.4.0)

### Features

* **api:** api update ([#18](https://github.com/Trellis-insights/trellis-python-sdk/issues/18)) ([bb5ab13](https://github.com/Trellis-insights/trellis-python-sdk/commit/bb5ab132cfc7f0576aa5ea0ed21e8e3bb622d684))

## 2.3.0 (2024-11-10)

Full Changelog: [v2.2.0...v2.3.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.2.0...v2.3.0)

### Features

* **api:** api update ([#15](https://github.com/Trellis-insights/trellis-python-sdk/issues/15)) ([6b673e1](https://github.com/Trellis-insights/trellis-python-sdk/commit/6b673e1a993e881471a55a5a16923a44b5bc9eae))

## 2.2.0 (2024-11-10)

Full Changelog: [v2.1.0...v2.2.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.1.0...v2.2.0)

### Features

* **api:** manual updates ([#12](https://github.com/Trellis-insights/trellis-python-sdk/issues/12)) ([f17a6d7](https://github.com/Trellis-insights/trellis-python-sdk/commit/f17a6d79b8e757344a6ddef9b5210837b7907e65))

## 2.1.0 (2024-11-10)

Full Changelog: [v2.0.0...v2.1.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v2.0.0...v2.1.0)

### Features

* **api:** api update ([#10](https://github.com/Trellis-insights/trellis-python-sdk/issues/10)) ([ebdfa0f](https://github.com/Trellis-insights/trellis-python-sdk/commit/ebdfa0fc9e6ca38ad74fa0f7a4cc09a6d0e5f824))
* **api:** api update ([#8](https://github.com/Trellis-insights/trellis-python-sdk/issues/8)) ([d7eadfc](https://github.com/Trellis-insights/trellis-python-sdk/commit/d7eadfcb12a6433ef6e2fd8e855d101ed0448a5f))

## 2.0.0 (2024-11-07)

Full Changelog: [v1.0.0...v2.0.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v1.0.0...v2.0.0)

### Chores

* update SDK settings ([#5](https://github.com/Trellis-insights/trellis-python-sdk/issues/5)) ([d244250](https://github.com/Trellis-insights/trellis-python-sdk/commit/d244250f38ee062e0885904076fd841ca27593f1))

## 1.0.0 (2024-11-04)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/Trellis-insights/trellis-python-sdk/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* go live ([#1](https://github.com/Trellis-insights/trellis-python-sdk/issues/1)) ([15992d4](https://github.com/Trellis-insights/trellis-python-sdk/commit/15992d4245d6e4d1c8a82c18c854ffa74d8090c4))
* update SDK settings ([#3](https://github.com/Trellis-insights/trellis-python-sdk/issues/3)) ([161e906](https://github.com/Trellis-insights/trellis-python-sdk/commit/161e90633a5a1d70c5c8a87a507bbca521ecb2ba))
